# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.agent_creation_source import AgentCreationSource

class TestAgentCreationSource(unittest.TestCase):
    """AgentCreationSource unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AgentCreationSource:
        """Test AgentCreationSource
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AgentCreationSource`
        """
        model = AgentCreationSource()
        if include_optional:
            return AgentCreationSource(
                type = 'GCP',
                gcp_project_id = '',
                gcp_region = '',
                gcp_reasoning_engine_id = '',
                service_names = [
                    ''
                    ]
            )
        else:
            return AgentCreationSource(
                gcp_project_id = '',
                gcp_region = '',
                gcp_reasoning_engine_id = '',
        )
        """

    def testAgentCreationSource(self):
        """Test AgentCreationSource"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
